@@ -9,13 +9,21 @@ import markdown
 from jinja2 import Environment, FileSystemLoader
 
 from . import echo
-from .md import HighlightExtension
+from .md import HighlightExtension, HrefExtension, ImageExtension, DomEventExtension
 from . import event
 
 
 class Config(object):
     """small wrapper around the config module that takes care of what happens if
     the config file doesn't actually exist"""
+    # TODO -- fix this, the loaded module should be checked, then the default values
+    # like method
+    method = 'http'
+
+    @property
+    def base_url(self):
+        return u'{}//{}'.format(self.method, self.host)
+
     def __init__(self, project_dir):
         self.module = None
 
@@ -104,13 +112,20 @@ class Post(object):
         return modified
 
     @property
-    def url(self):
+    def uri(self):
+        """the path of the post (eg, /foo/bar/post-slug)"""
         d = self.directory
         relative = d.relative()
         relative = relative.replace('\\', '/')
         v = "/".join(['', relative])
         return v
 
+    @property
+    def url(self):
+        """the full url of the post with host and everything"""
+        base_url = self.config.base_url
+        return u"{}{}".format(base_url, self.uri)
+
     @property
     def title(self):
         d = self.directory
@@ -127,30 +142,16 @@ class Post(object):
 
     @property
     def html(self):
-        return self.render_html()
-
-    def __init__(self, directory, output_dir, tmpl):
-        self.directory = directory
-        self.output_dir = output_dir
-        self.tmpl = tmpl
-
-    def render_html(self, base_url=''):
         """
         return html of the post
 
-        base_url -- string -- if passed in, file links will be changed to base_url + post_url ++ filename
+        base_url -- string -- if passed in, file links will be changed to base_url + post_url + filename
 
         return -- string -- rendered html
         """
         d = self.directory
         ext = os.path.splitext(d.content_file)[1][1:]
         body = self.body
-        permalink = self.url
-        for input_file in d.other_files:
-            basename = os.path.basename(input_file)
-            file_permalink = "{}{}/{}".format(base_url, permalink, basename)
-            body = body.replace(basename, file_permalink)
-
         ext_callback = getattr(self, "normalize_{}".format(ext), None)
         if ext_callback:
             html = ext_callback(body)
@@ -160,16 +161,35 @@ class Post(object):
         return html
 
 
+    def __init__(self, directory, output_dir, tmpl, config):
+        self.directory = directory
+        self.output_dir = output_dir
+        self.tmpl = tmpl
+        self.config = config
+
     def normalize_markdown(self, text):
         """alternate file extension .markdown should point to .md"""
         return self.normalize_md(text)
 
     def normalize_md(self, text):
-        # http://packages.python.org/Markdown/extensions/index.html
+        """normalize markdown using the markdown module https://github.com/waylan/Python-Markdown"""
+        # http://pythonhosted.org/Markdown/reference.html#markdown
         return markdown.markdown(
             text, 
             #extensions=['fenced_code', 'codehilite(guess_lang=False)', 'tables', 'footnotes', 'nl2br']
-            extensions=[HighlightExtension(), 'tables', 'footnotes(UNIQUE_IDS=True)', 'nl2br']
+            # http://packages.python.org/Markdown/extensions/index.html
+            extensions=[
+                HighlightExtension(),
+                'tables',
+                'footnotes(UNIQUE_IDS=True)',
+                'nl2br',
+                'attr_list',
+                'smart_strong',
+                HrefExtension(self),
+                ImageExtension(self),
+                DomEventExtension(self)
+            ],
+            output_format="html5"
         )
 
     def __str__(self):
@@ -225,12 +245,12 @@ class Site(object):
             output_dir = self.output_dir / d.relative()
             if d.is_aux():
                 echo.out("aux dir: {}", d)
-                a = Aux(d, output_dir, tmpl)
+                a = Aux(d, output_dir, tmpl, self.config)
                 auxs.append(a)
 
             elif d.is_post():
                 echo.out("post dir: {}", d)
-                p = Post(d, output_dir, tmpl)
+                p = Post(d, output_dir, tmpl, self.config)
                 posts.append(p)
 
             else:
